@@ -24,7 +24,7 @@ _LOGGER = logging.getLogger("DenonAVR")
 
 DEVICEINFO_AVR_X_PATTERN = re.compile(
     r"(.*AV(C|R)-(X|S).*|.*SR500[6-9]|.*SR60(07|08|09|10|11|12|13)|."
-    r"*SR70(07|08|09|10|11|12|13)|.*NR1604|.*NR1710)")
+    r"*SR70(07|08|09|10|11|12|13)|.*SR501[3-4]|.*NR1604|.*NR1710)")
 
 DEVICEINFO_COMMAPI_PATTERN = re.compile(r"(0210|0300|0301)")
 
@@ -56,7 +56,7 @@ SOUND_MODE_MAPPING = OrderedDict(
                 'DTS NEO:X MUSIC', 'DOLBY PL2 MUSIC']),
      ('MOVIE', ['PLII MOVIE', 'PLII CINEMA', 'DTS NEO:X CINEMA',
                 'DTS NEO:6 CINEMA', 'DOLBY D +NEO:X C',
-                'PLIIX CINEMA']),
+                'PLIIX CINEMA', 'DOLBY PLII MOVIE']),
      ('GAME', ['PLII GAME', 'DOLBY D +NEO:X G']),
      ('AUTO', ['None']),
      ('STANDARD', ['None2']),
@@ -81,7 +81,8 @@ SOUND_MODE_MAPPING = OrderedDict(
                         'DOLBY AUDIO - TRUEHD + NEURAL:X',
                         'DOLBY AUDIO - DD + DSUR',
                         'DOLBY AUDIO - DD+   + NEURAL:X',
-                        'DOLBY AUDIO - DD+   + DSUR']),
+                        'DOLBY AUDIO - DD+   + DSUR',
+                        'DOLBY AUDIO - DOLBY DIGITAL']),
      ('DTS SURROUND', ['DTS SURROUND', 'DTS NEURAL:X', 'STANDARD(DTS)',
                        'DTS + NEURAL:X', 'MULTI CH IN', 'DTS-HD MSTR',
                        'DTS VIRTUAL:X', 'DTS-HD + NEURAL:X', 'DTS-HD',
@@ -470,7 +471,7 @@ class DenonAVR:
                 executor.submit(self.get_device_info)
 
             if self._receiver_type == AVR_X_2016.type:
-                executor.submit(self._get_zone_name)
+                executor.submit(self._get_receiver_name_avr_2016)
             else:
                 executor.submit(self._get_receiver_name)
 
@@ -837,11 +838,11 @@ class DenonAVR:
                                     "Using standard name: Denon AVR.")
                     self._name = "Denon AVR"
 
-    def _get_zone_name(self):
-        """Get receivers zone name if not set yet."""
+    def _get_receiver_name_avr_2016(self):
+        """Get name of receiver from web interface if not set."""
         if self._name is None:
             # Collect tags for AppCommand.xml call
-            tags = ["GetZoneName"]
+            tags = ["GetFriendlyName"]
             # Execute call
             try:
                 root = self.exec_appcommand_post(tags)
@@ -849,15 +850,13 @@ class DenonAVR:
                 root = None
             # Check result
             if root is None:
-                _LOGGER.error("Getting ZoneName failed.")
+                _LOGGER.error("Getting GetFriendlyName failed.")
                 return
 
-            zone = self._get_own_zone()
             try:
-                name = root.find(
-                    "./cmd/{zone}".format(zone=zone)).text
+                name = root.find("./cmd/friendlyname").text
             except AttributeError:
-                _LOGGER.error("No ZoneName found for zone %s", self.zone)
+                _LOGGER.error("No friendlyname found")
             else:
                 self._name = name.strip()
 
@@ -1715,7 +1714,7 @@ class DenonAVR:
             self._sound_mode_dict[smr_up] = [smr_up]
             self._sm_match_dict = self.construct_sm_match_dict()
             _LOGGER.warning("Not able to match sound mode: '%s', "
-                            "returning raw sound mode.", sound_mode_raw)
+                            "returning raw sound mode.", smr_up)
         return sound_mode_raw
 
     def toggle_play_pause(self):
